class AthleteList(list):
    def __init__(self, a_name, a_dob=None, a_times=[]):
        list.__init__([])
        self.name = a_name
        self.dob = a_dob
        self.extend(a_times)

    def top3(self):
        return(sorted(set([sanitize(t) for t in self]))[0:3])



from distutils.core import setup

setup(
		name = 'zathleteListClass',
		version = '1.0.0',
		py_modules = ['zathleteListClass'],
		author = 'surf',
		author_email = 'surfielda@aol.com',
		url = 'http://www.zurfgames.com',
		description = 'A simple printer of athlete lists',
	 )